@@ -1605,7 +1605,9 @@ glade_gnome_bonobodockitem_get_props (BonoboDock *doc,
 			return TRUE;
 		}
         }
-        
+
+	g_warning ("Item not found in BonoboDock");
+	
         return FALSE;
 }
 
@@ -1638,41 +1640,44 @@ glade_gnome_bonobodock_set_child_property (GladeWidgetAdaptor  *adaptor,
 	}
 	
 	wchild = GTK_WIDGET (child);
-	glade_gnome_bonobodockitem_get_props (dock, item, &placement, &band_num,
-					      &band_position, &offset);
 	
-	if (strcmp ("placement", property_name) == 0)
-		placement = g_value_get_enum (value);
-	else if (strcmp ("position", property_name) == 0)
-		band_position = g_value_get_int (value);
-	else if (strcmp ("band", property_name) == 0)
-		band_num = g_value_get_int (value);
-	else if (strcmp ("offset", property_name) == 0)
-		offset = g_value_get_int (value);
-	else
+	if (glade_gnome_bonobodockitem_get_props (dock, item, &placement, &band_num,
+						  &band_position, &offset))
 	{
-		g_warning ("No BonoboDock set packing property support for '%s'.", property_name);
-		return;
-	}
-	
-	if ((band = glade_gnome_bd_get_band (dock, wchild)))
-	{		
-		g_object_ref (child);
-		gtk_container_remove (GTK_CONTAINER (band), wchild);
-		
-		if (band->num_children == 0)
+		if (strcmp ("placement", property_name) == 0)
+			placement = g_value_get_enum (value);
+		else if (strcmp ("position", property_name) == 0)
+			band_position = g_value_get_int (value);
+		else if (strcmp ("band", property_name) == 0)
+			band_num = g_value_get_int (value);
+		else if (strcmp ("offset", property_name) == 0)
+			offset = g_value_get_int (value);
+		else
 		{
-			new_band = TRUE;
-			gtk_container_remove (GTK_CONTAINER (container), GTK_WIDGET(band));
+			g_warning ("No BonoboDock set packing property support for '%s'.", property_name);
+			return;
 		}
+	
+		if ((band = glade_gnome_bd_get_band (dock, wchild)))
+		{
+			g_object_ref (child);
+			gtk_container_remove (GTK_CONTAINER (band), wchild);
 		
-		bonobo_dock_add_item (dock, item, placement, band_num, 
-				      band_position, offset, new_band);
-		bonobo_dock_item_set_behavior (item, item->behavior);
-		g_object_unref (child);
+			if (band->num_children == 0)
+			{
+				new_band = TRUE;
+				gtk_container_remove (GTK_CONTAINER (container),
+						      GTK_WIDGET(band));
+			}
+		
+			bonobo_dock_add_item (dock, item, placement, band_num, 
+					      band_position, offset, new_band);
+			bonobo_dock_item_set_behavior (item, item->behavior);
+			g_object_unref (child);
+		}
+		else
+			g_warning ("BonoboDockItem's band not found.\n");
 	}
-	else
-		g_warning ("BonoboDockItem's band not found.\n");
 }
 
 void
@@ -1699,19 +1704,20 @@ glade_gnome_bonobodock_get_child_property (GladeWidgetAdaptor  *adaptor,
 		return;
 	}
 	
-	glade_gnome_bonobodockitem_get_props (BONOBO_DOCK (container),
-					      BONOBO_DOCK_ITEM (child),
-					      &placement, &band_num,
-					      &band_position, &offset);
-	
-	if (strcmp ("placement", property_name) == 0)
-		g_value_set_enum (value, placement);
-	else if (strcmp ("position", property_name) == 0)
-		g_value_set_int (value, band_position);
-	else if (strcmp ("band", property_name) == 0)
-		g_value_set_int (value, band_num);
-	else if (strcmp ("offset", property_name) == 0)
-		g_value_set_int (value, offset);
+	if (glade_gnome_bonobodockitem_get_props (BONOBO_DOCK (container),
+						  BONOBO_DOCK_ITEM (child),
+						  &placement, &band_num,
+						  &band_position, &offset))
+	{	
+		if (strcmp ("placement", property_name) == 0)
+			g_value_set_enum (value, placement);
+		else if (strcmp ("position", property_name) == 0)
+			g_value_set_int (value, band_position);
+		else if (strcmp ("band", property_name) == 0)
+			g_value_set_int (value, band_num);
+		else if (strcmp ("offset", property_name) == 0)
+			g_value_set_int (value, offset);
+	}
 }
 
 void
